@@ -9,13 +9,13 @@ import (
 
 type GlobalContext struct {
 	workDir string
-	job     map[string]string
+	job     JobVariables
 	env     *Environment
 	stdout  io.Writer
 	stderr  io.Writer
 }
 
-func NewGlobalContext(workDir string, job map[string]string, env *Environment, stdout, stderr io.Writer) *GlobalContext {
+func NewGlobalContext(workDir string, job JobVariables, env *Environment, stdout, stderr io.Writer) *GlobalContext {
 	precond.MustNotBeNil(env, "global context must have an environment")
 
 	return &GlobalContext{
@@ -31,7 +31,7 @@ func (gc *GlobalContext) WorkDir() string {
 	return gc.workDir
 }
 
-func (gc *GlobalContext) Job() map[string]string {
+func (gc *GlobalContext) Job() JobVariables {
 	return gc.job
 }
 
